.. highlight:: shell

Installation
**********************

gabrieltool Python Library
---------------------------

First, make sure Docker is installed. You can follow the `Docker installation
guide <https://docs.docker.com/get-docker/>`_.

Option 1. From PyPI (recommended)

.. code-block:: console

    $ pip install -U gabrieltool

Option 2. From Source

.. code-block:: console

    $ git clone https://github.com/cmusatyalab/OpenWorkflow.git
    $ cd OpenWorkflow/
    $ python setup.py install

OpenWorkflow State Machine Web Editor
---------------------------------------------------

Visit `<https://cmusatyalab.github.io/OpenWorkflow>`_. Or You can download the
build from the repo's `gh-pages branch 
<https://github.com/cmusatyalab/OpenWorkflow/archive/gh-pages.zip>`_ and open
the index.html.